@@ -39,6 +39,14 @@ key_press_event_cb (GtkWidget *widget, GdkEventKey *event, gpointer data)
   return gtk_interface->handle_keypress_event (event);
 }
 
+static gboolean
+button_press_event_cb (GtkWidget *widget, GdkEventButton *event, gpointer data)
+{
+  GtkInterface *gtk_interface = static_cast<GtkInterface *> (data);
+
+  return gtk_interface->handle_buttonpress_event (event);
+}
+
 static gboolean
 motion_notify_event_cb (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 {
@@ -106,7 +114,9 @@ GtkInterface::init (int *argc, char ***argv, KeyHandler *handler)
     {
       gtk_init (argc, argv);
       gtk_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+      gtk_window_set_icon_name (GTK_WINDOW (gtk_window), "multimedia-player");
       g_signal_connect (G_OBJECT (gtk_window), "key-press-event", G_CALLBACK (key_press_event_cb), this);
+      g_signal_connect (G_OBJECT (gtk_window), "button-press-event", G_CALLBACK (button_press_event_cb), this);
       g_signal_connect (G_OBJECT (gtk_window), "motion-notify-event", G_CALLBACK (motion_notify_event_cb), this);
       g_signal_connect (G_OBJECT (gtk_window), "delete-event", G_CALLBACK (close_cb), this);
       g_signal_connect (G_OBJECT (gtk_window), "window-state-event", G_CALLBACK (window_state_event_cb), this);
@@ -119,12 +129,16 @@ GtkInterface::init (int *argc, char ***argv, KeyHandler *handler)
       video_fullscreen = Options::the().fullscreen;    // initially fullscreen?
 
       // make background black
-      GdkColor color;
-      gdk_color_parse ("black", &color);
-      gtk_widget_modify_bg (gtk_window, GTK_STATE_NORMAL, &color);
+      GtkCssProvider *provider = gtk_css_provider_new();
+      gtk_css_provider_load_from_data (provider, "window {background-color: black;}\n", -1, NULL);
+
+      GtkStyleContext* style_context = gtk_widget_get_style_context (gtk_window);
+      gtk_style_context_add_provider (style_context, GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+      g_object_unref (provider);
 
       visible_cursor = NULL;
-      invisible_cursor = gdk_cursor_new (GDK_BLANK_CURSOR);
+      GdkDisplay *display = gdk_display_get_default();
+      invisible_cursor = gdk_cursor_new_for_display (display, GDK_BLANK_CURSOR);
 
       cursor_timeout = 3;
       g_timeout_add (500, (GSourceFunc) timeout_cb, this);
@@ -136,15 +150,15 @@ GtkInterface::init (int *argc, char ***argv, KeyHandler *handler)
   gtk_window_visible = false;
 
   /* initialize map from Gdk keysyms to KeyHandler codes */
-  key_map[GDK_Page_Up]     = KEY_HANDLER_PAGE_UP;
-  key_map[GDK_Page_Down]   = KEY_HANDLER_PAGE_DOWN;
-  key_map[GDK_Left]        = KEY_HANDLER_LEFT;
-  key_map[GDK_Right]       = KEY_HANDLER_RIGHT;
-  key_map[GDK_Up]          = KEY_HANDLER_UP;
-  key_map[GDK_Down]        = KEY_HANDLER_DOWN;
-  key_map[GDK_BackSpace]   = KEY_HANDLER_BACKSPACE;
-  key_map[GDK_KP_Add]      = '+';
-  key_map[GDK_KP_Subtract] = '-';
+  key_map[GDK_KEY_Page_Up]     = KEY_HANDLER_PAGE_UP;
+  key_map[GDK_KEY_Page_Down]   = KEY_HANDLER_PAGE_DOWN;
+  key_map[GDK_KEY_Left]        = KEY_HANDLER_LEFT;
+  key_map[GDK_KEY_Right]       = KEY_HANDLER_RIGHT;
+  key_map[GDK_KEY_Up]          = KEY_HANDLER_UP;
+  key_map[GDK_KEY_Down]        = KEY_HANDLER_DOWN;
+  key_map[GDK_KEY_BackSpace]   = KEY_HANDLER_BACKSPACE;
+  key_map[GDK_KEY_KP_Add]      = '+';
+  key_map[GDK_KEY_KP_Subtract] = '-';
 }
 
 bool
@@ -152,7 +166,7 @@ GtkInterface::is_fullscreen()
 {
   g_return_val_if_fail (gtk_window != NULL && gtk_window_visible, false);
 
-  GdkWindowState state = gdk_window_get_state (GDK_WINDOW (gtk_window->window));
+  GdkWindowState state = gdk_window_get_state (gtk_widget_get_window (gtk_window));
   return (state & GDK_WINDOW_STATE_FULLSCREEN);
 }
 
@@ -161,7 +175,7 @@ GtkInterface::is_maximized()
 {
   g_return_val_if_fail (gtk_window != NULL && gtk_window_visible, false);
 
-  GdkWindowState state = gdk_window_get_state (GDK_WINDOW (gtk_window->window));
+  GdkWindowState state = gdk_window_get_state (gtk_widget_get_window (gtk_window));
   return (state & GDK_WINDOW_STATE_MAXIMIZED);
 }
 
@@ -209,7 +223,7 @@ GtkInterface::show()
 
       // get cursor, so we can restore it after hiding it
       if (!visible_cursor)
-        visible_cursor = gdk_window_get_cursor (GDK_WINDOW (gtk_window->window));
+        visible_cursor = gdk_window_get_cursor (gtk_widget_get_window (gtk_window));
 
       // sync, to make the window really visible before we return
       gdk_display_sync (gdk_display_get_default());
@@ -270,7 +284,7 @@ GtkInterface::hide()
       if (video_maximized)
         gtk_window_unmaximize (GTK_WINDOW (gtk_window));
 
-      gtk_widget_hide_all (gtk_window);
+      gtk_widget_hide (gtk_window);
 
       screen_saver (RESUME);
       gtk_window_visible = false;
@@ -341,10 +355,10 @@ GtkInterface::set_opacity (double alpha_change)
     {
       double alpha;
 
-      alpha = gtk_window_get_opacity (GTK_WINDOW (gtk_window));
+      alpha = gtk_widget_get_opacity (GTK_WIDGET (gtk_window));
       alpha = CLAMP (alpha + alpha_change, 0.0, 1.0);
       Msg::update_status ("Opacity: %3.1f%%", alpha * 100);
-      gtk_window_set_opacity (GTK_WINDOW (gtk_window), alpha);
+      gtk_widget_set_opacity (GTK_WIDGET (gtk_window), alpha);
     }
 }
 
@@ -366,6 +380,17 @@ GtkInterface::handle_keypress_event (GdkEventKey *event)
   return false;
 }
 
+bool
+GtkInterface::handle_buttonpress_event (GdkEventButton *event)
+{
+  if (event->button == 1 && event->state == 0)
+    {
+      key_handler->process_input (' ');
+      return true;
+    }
+  return false;
+}
+
 void
 GtkInterface::set_title (const string& title)
 {
@@ -380,7 +405,7 @@ GtkInterface::handle_timeout()
     {
       if (cursor_timeout == 0)
         {
-          gdk_window_set_cursor (GDK_WINDOW (gtk_window->window), invisible_cursor);
+          gdk_window_set_cursor (gtk_widget_get_window (gtk_window), invisible_cursor);
           cursor_timeout = -1;
         }
       else if (cursor_timeout > 0)
@@ -396,7 +421,7 @@ GtkInterface::handle_motion_notify_event (GdkEventMotion *event)
 {
   if (gtk_window != NULL && gtk_window_visible)
     {
-      gdk_window_set_cursor (GDK_WINDOW (gtk_window->window), visible_cursor);
+      gdk_window_set_cursor (gtk_widget_get_window (gtk_window), visible_cursor);
       cursor_timeout = 3;
     }
   return true;
@@ -438,10 +463,10 @@ GtkInterface::handle_close()
 void
 GtkInterface::screen_saver (ScreenSaverSetting setting)
 {
-  GdkWindow *window = GTK_WIDGET (gtk_window)->window;
+  GdkWindow *window = gtk_widget_get_window (gtk_window);
   if (gtk_window != NULL && window)
     {
-      guint64 wid = GDK_WINDOW_XWINDOW (window);
+      guint64 wid = GDK_WINDOW_XID (window);
 
       const char *setting_str = (setting == SUSPEND) ? "suspend" : "resume";
 
