@@ -20,15 +20,21 @@
 #ifndef __GST123_MSG__
 #define __GST123_MSG__
 
+#include <string>
+#include <glib.h>
+
 namespace Gst123
 {
 
 namespace Msg
 {
 
-void print (const char *format, ...);
+void print (const char *format, ...) G_GNUC_PRINTF (1, 2);
 void flush();
 
+void update_status (const char *format, ...) G_GNUC_PRINTF (1, 2);
+std::string status();
+
 }
 
 }
