@@ -44,11 +44,13 @@ Options::Options ()
   verbose = FALSE;
   novideo = FALSE;
   quiet   = FALSE;
+  fullscreen = FALSE;
   uris = NULL;
   audio_output = NULL;
   print_visualization_list = FALSE;
   visualization = NULL;
   skip = 0;
+  initial_volume = -1; // don't touch volume setting when started
 
   string default_audio_output = ConfigFile::the().audio_output();
   if (default_audio_output != "")
@@ -66,32 +68,38 @@ Options::parse (int argc, char **argv)
   GOptionContext *context = g_option_context_new ("<URI>... - Play video and audio clips");
   const GOptionEntry all_options[] = {
     {"list", '@', G_OPTION_FLAG_FILENAME, G_OPTION_ARG_CALLBACK,
-      (GOptionParseFunc*) Options::add_playlist,
-      "read playlist of files and URIs from <filename>", "<filename>"},
+      gpointer (static_cast<GOptionArgFunc> (Options::add_playlist)),
+      "Read playlist of files and URIs from <filename>", "<filename>"},
     {"version", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
-      (GOptionParseFunc*) Options::print_version, "print version", NULL },
+      gpointer (static_cast<GOptionArgFunc> (Options::print_version)), "Print version", NULL },
     {"full-version", '\0', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
-      (GOptionParseFunc*) Options::print_full_version, "print full version", NULL },
+      gpointer (static_cast<GOptionArgFunc> (Options::print_full_version)), "Print full version", NULL },
     {"verbose", '\0', 0, G_OPTION_ARG_NONE, &instance->verbose,
-      "print GStreamer pipeline used to play files", NULL},
+      "Print GStreamer pipeline used to play files", NULL},
     {"repeat", 'r', 0, G_OPTION_ARG_NONE, &instance->repeat,
-      "repeat playlist forever", NULL},
+      "Repeat playlist forever", NULL},
     {"shuffle", 'z', 0, G_OPTION_ARG_NONE, &instance->shuffle,
-      "shuffle playlist before playing", NULL},
+      "Shuffle playlist before playing", NULL},
     {"random",  'Z', 0, G_OPTION_ARG_NONE, &random,
-      "play files in random order forever", NULL},
+      "Play files in random order forever", NULL},
     {"novideo", 'x', 0, G_OPTION_ARG_NONE, &instance->novideo,
-      "do not play the video stream", NULL},
+      "Do not play the video stream", NULL},
+    {"fullscreen", 'f', 0, G_OPTION_ARG_NONE, &instance->fullscreen,
+      "Use fullscreen video output", NULL},
     {"audio-output", 'a', 0, G_OPTION_ARG_STRING, &instance->audio_output,
-      "set audio output driver and device", "<driver>[=<dev>]"},
+      "Set audio output driver and device", "<driver>[=<dev>]"},
     {"visualization", 'v', 0, G_OPTION_ARG_STRING, &instance->visualization,
-      "set visualization plugin to use for audio playback", "<plugin_name>"},
+      "Set visualization plugin to use for audio playback", "<plugin_name>"},
     {"visualization-list", 'V', 0, G_OPTION_ARG_NONE, &instance->print_visualization_list,
-      "show available visualization plugins", NULL },
+      "Show available visualization plugins", NULL },
     {"skip", 'k', 0, G_OPTION_ARG_DOUBLE, &instance->skip,
       "Skip the first 'n' seconds", "<n>"},
+    { "volume", '\0', 0, G_OPTION_ARG_DOUBLE, &instance->initial_volume,
+      "Set initial replay volume (in percent)", "<volume>" },
+    {"subtitle", 's', 0, G_OPTION_ARG_STRING, &instance->subtitle,
+      "Set subtitle file to use for video playback", "<subtitle_file>"},
     {"quiet", 'q', 0, G_OPTION_ARG_NONE, &instance->quiet,
-      "don't display any messages", NULL},
+      "Don't display any messages", NULL},
     {G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &instance->uris, "Movies to play", NULL},
     {NULL} /* end the list */
   };
@@ -120,15 +128,15 @@ Options::parse (int argc, char **argv)
     }
 }
 
-void
-Options::print_version()
+gboolean
+Options::print_version (const gchar *option_name, const gchar *value, gpointer data, GError **error)
 {
   printf ("%s %s\n", instance->program_name.c_str(), VERSION);
   exit (0);
 }
 
-void
-Options::print_full_version()
+gboolean
+Options::print_full_version (const gchar *option_name, const gchar *value, gpointer data, GError **error)
 {
   printf ("%-10s %s\n", (instance->program_name + ":").c_str(), VERSION);
   printf ("%-10s %d.%d.%d-%d\n", "GStreamer:", GST_VERSION_MAJOR, GST_VERSION_MINOR, GST_VERSION_MICRO, GST_VERSION_NANO);
@@ -138,13 +146,15 @@ Options::print_full_version()
   exit (0);
 }
 
-void
-Options::add_playlist (const gchar *option_name, const gchar *value)
+gboolean
+Options::add_playlist (const gchar *option_name, const gchar *value, gpointer data, GError **error)
 {
   instance->playlists.push_back (value);
+
+  return TRUE;
 }
 
-Options&
+const Options&
 Options::the()
 {
   assert (instance);
