@@ -27,9 +27,9 @@ class Options
 {
   static Options *instance;
 
-  static void print_version();
-  static void print_full_version();
-  static void add_playlist (const gchar *option_name, const gchar *value);
+  static gboolean print_version (const gchar *option_name, const gchar *value, gpointer data, GError **error);
+  static gboolean print_full_version (const gchar *option_name, const gchar *value, gpointer data, GError **error);
+  static gboolean add_playlist (const gchar *option_name, const gchar *value, gpointer data, GError **error);
 
 public:
   std::string	program_name; /* FIXME: what to do with that */
@@ -42,16 +42,19 @@ public:
   gboolean      novideo;
   gboolean      print_visualization_list;
   double        skip;
+  double        initial_volume;
   gboolean      quiet;
+  gboolean      fullscreen;
   char        **uris;
   std::list<std::string>  playlists;
   char         *audio_output;
+  char         *subtitle;
   char         *visualization;
 
   Options ();
   void parse (int argc, char **argv);
 
-  static Options& the();
+  static const Options& the();
 };
 
 #endif
